Struct plaid::investment_transactions::GetInvestmentTransactionsResponse[][src]

pub struct GetInvestmentTransactionsResponse {
    pub request_id: String,
    pub accounts: Vec<Account>,
    pub securities: Vec<Security>,
    pub investment_transactions: Vec<InvestmentTransaction>,
    pub total_investment_transactions: i32,
    pub item: Item,
}

Fields

request_id: String

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

accounts: Vec<Account>

The accounts for which transaction history is being fetched.

securities: Vec<Security>

All securities for which there is a corresponding transaction being fetched.

investment_transactions: Vec<InvestmentTransaction>

The transactions being fetched

total_investment_transactions: i32

The total number of transactions available within the date range specified.

item: Item

Metadata about the Item.