Struct plaid::investment_transactions::InvestmentTransaction[][src]

pub struct InvestmentTransaction {
    pub investment_transaction_id: String,
    pub cancel_transaction_id: Option<String>,
    pub account_id: String,
    pub security_id: Option<String>,
    pub date: NaiveDate,
    pub name: String,
    pub quantity: f64,
    pub amount: f64,
    pub price: f64,
    pub fees: Option<f64>,
    pub type: String,
    pub subtype: String,
    pub iso_currency_code: Option<String>,
    pub unofficial_currency_code: Option<String>,
}

Fields

investment_transaction_id: String

The ID of the Investment transaction, unique across all Plaid transactions. Like all Plaid identifiers, the investment_transaction_id is case sensitive.

cancel_transaction_id: Option<String>account_id: String

The account_id of the account against which this transaction posted.

security_id: Option<String>

The security_id to which this transaction is related.

date: NaiveDate

The ISO-8601 posting date for the transaction, or transacted date for pending transactions.

name: String

The institution’s description of the transaction.

quantity: f64

The number of units of the security involved in this transactions

amount: f64

The complete value of the transaction.

price: f64

The price of the security at which this transaction occurred.

fees: Option<f64>

The combined value of all fees applied to this transaction

type: String

Possible values: buy, sell, cancel, cash, fee, transfer

subtype: String

transaction subtype

iso_currency_code: Option<String>

The ISO-4217 currency code of the transaction. Always null if unofficial_currency_code is non-null.

unofficial_currency_code: Option<String>

The unofficial currency code associated with the holding.