Struct plaid::investment_transactions::InvestmentTransaction [−][src]
Fields
investment_transaction_id: StringThe ID of the Investment transaction, unique across all Plaid transactions. Like all Plaid identifiers, the investment_transaction_id is case sensitive.
cancel_transaction_id: Option<String>account_id: StringThe account_id of the account against which this transaction posted.
security_id: Option<String>The security_id to which this transaction is related.
date: NaiveDateThe ISO-8601 posting date for the transaction, or transacted date for pending transactions.
name: StringThe institution’s description of the transaction.
quantity: f64The number of units of the security involved in this transactions
amount: f64The complete value of the transaction.
price: f64The price of the security at which this transaction occurred.
fees: Option<f64>The combined value of all fees applied to this transaction
type: StringPossible values: buy, sell, cancel, cash, fee, transfer
subtype: Stringtransaction subtype
iso_currency_code: Option<String>The ISO-4217 currency code of the transaction. Always null if unofficial_currency_code is non-null.
unofficial_currency_code: Option<String>The unofficial currency code associated with the holding.